<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package WordPress
 * @subpackage Digger
 * @since Digger 1.0.3
 */

if ( post_password_required() ) {
	return;
}
?>
<div id="comments" class="comments-area">

	<?php
	if ( have_comments() ) {
		?>
		<h2 class="comments-title mb-3 mb-md-5">
			<?php esc_html_e( 'Comments', 'digger' ); ?> 
		</h2>

		<?php
		if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) { // Are there comments to navigate through?
			?>
			<h3 class="screen-reader-text sr-only"><?php esc_html_e( 'Comment navigation', 'digger' ); ?></h3>
			<ul id="comment-nav-above" class="comment-navigation pager" role="navigation">
				<li class="nav-previous previous"><?php previous_comments_link( __( '&larr; Old comments', 'digger' ) ); ?></li>
				<li class="nav-next next"><?php next_comments_link( __( 'New comments &rarr;', 'digger' ) ); ?></li>
			</ul><!-- #comment-nav-above -->
			<?php
		} // check for comment navigation
		?>

		<ul class="media-list">
		<?php
		wp_list_comments(
			array(
				'avatar_size' => '38',
				'callback'    => 'digger_comment',
			)
		);
		?>
		</ul>

		<?php
		if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) { // Are there comments to navigate through?
			?>
			<h3 class="screen-reader-text sr-only"><?php esc_html_e( 'Comment navigation', 'digger' ); ?></h3>
			<ul id="comment-nav-below" class="comment-navigation comment-navigation-below pager" role="navigation">
				<li class="nav-previous previous"><?php previous_comments_link( __( '&larr; Old comments', 'digger' ) ); ?></li>
				<li class="nav-next next"><?php next_comments_link( __( 'New comments &rarr;', 'digger' ) ); ?></li>
			</ul><!-- #comment-nav-below -->
			<?php
		} // Check for comment navigation.
		?>

		<?php
	}
	?>

	<?php
	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && '0' !== get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) {
		?>
		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'digger' ); ?></p>
		<?php
	} //endif;
	?>

	<?php
	$digger_req      = get_option( 'require_name_email' );
	$digger_aria_req = ( $digger_req ? " aria-required='true'" : '' );
	$digger_html5    = true;

	// Re-format comment allowed tags.
	$digger_comment_allowedtags           = allowed_tags();
	$digger_comment_allowedtags           = str_replace( array( "\r\n", "\r", "\n" ), '', $digger_comment_allowedtags );
	$digger_comment_allowedtags_array     = explode( '&gt; &lt;', $digger_comment_allowedtags );
	$digger_formatted_comment_allowedtags = '';
	foreach ( $digger_comment_allowedtags_array as $digger_item ) {
		$digger_formatted_comment_allowedtags .= '<code>';

		if ( $digger_comment_allowedtags_array[0] !== $digger_item ) {
			$digger_formatted_comment_allowedtags .= '&lt;';
		}

		$digger_formatted_comment_allowedtags .= $digger_item;

		if ( end( $digger_comment_allowedtags_array ) !== $digger_item ) {
			$digger_formatted_comment_allowedtags .= '&gt;';
		}

		$digger_formatted_comment_allowedtags .= '</code> ';
	}
	$digger_comment_allowed_tags = $digger_formatted_comment_allowedtags;
	unset( $digger_comment_allowedtags, $digger_comment_allowedtags_array, $digger_formatted_comment_allowedtags );

	comment_form(
		array(
			'class_submit'  => 'btn btn-primary',
			'fields'        => array(
				'author' => '<div class="mb-3">' .
							'<label class="form-label" for="author">' . __( 'Name', 'digger' ) . ( $digger_req ? ' <span class="required">*</span>' : '' ) . '</label> ' .
							'<div class="col-md-10">' .
							'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $digger_aria_req . ' class="form-control" />' .
							'</div>' .
							'</div>',
				'email'  => '<div class="mb-3">' .
							'<label class="form-label" for="email">' . __( 'Email', 'digger' ) . ( $digger_req ? ' <span class="required">*</span>' : '' ) . '</label> ' .
							'<div class="col-md-10">' .
							'<input id="email" name="email" ' . ( $digger_html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30"' . $digger_aria_req . ' class="form-control" />' .
							'</div>' .
							'</div>',
			),
			'comment_field' => '<div class="mb-3">' .
							'<label class="form-label" for="comment">' . __( 'Message', 'digger' ) . '</label> ' .
							'<div class="col-md-10">' .
							'<textarea id="comment" name="comment" rows="3" aria-required="true" class="form-control"></textarea>' .
							'</div>' .
							'</div>',
		)
	);
	unset( $digger_comment_allowed_tags );
	?>

</div><!-- #comments -->
