<?php
/**
 * Functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage Digger
 * @since Digger 1.0.3
 */

/**
 * DIGGER THEME LANGUAGES
 */
load_theme_textdomain( 'digger', get_template_directory() . '/languages' );

/**
 * DIGGER THEME OPTIONS
 */
function digger_setup() {
	// Add support for block styles.
	add_theme_support( 'wp-block-styles' );
	add_theme_support(
		'html5',
		array(
			'comment-list',
			'comment-form',
			'search-form',
		)
	);
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'custom-background' );
	add_theme_support(
		'custom-logo',
		array(
			'height'               => 30,
			'width'                => 30,
			'flex-width'           => false,
			'flex-height'          => false,
			'header-text'          => '',
			'unlink-homepage-logo' => false, // For WordPress 5.5.
		)
	);

	register_nav_menus(
		array(
			'primary' => esc_html__( 'Primary', 'digger' ),
			'footer'  => esc_html__( 'Footer', 'digger' ),
		)
	);
}
add_action( 'after_setup_theme', 'digger_setup' );
/**
 * DIGGER THEME SCRIPTS
 */
function digger_scripts() {
	wp_enqueue_script( 'digger-bootstrapjs', get_template_directory_uri() . '/js/bootstrap.bundle.min.js', array(), '1.0.2', true );
	wp_enqueue_style( 'dashicons' );
	wp_enqueue_style( 'digger-bootstrap-css', get_template_directory_uri() . '/css/bootstrap.min.css', array(), '1.0.2' );
	wp_enqueue_style( 'digger-style', get_stylesheet_uri(), array(), '1.0.2' );
}
add_action( 'wp_enqueue_scripts', 'digger_scripts' );
/**
 * DIGGER THEME INCLUDES
 */
if ( ! class_exists( 'digger_navwalker' ) ) {
	require_once get_template_directory() . '/includes/class-digger-navwalker.php';
}
require_once get_stylesheet_directory() . '/includes/digger-pagination.php';
require_once get_stylesheet_directory() . '/includes/digger-comments.php';
/**
 * DIGGER WIDGET FOOTER AREA
 */
add_action( 'widgets_init', 'digger_register_custom_widget_area' );
/**
 * Function, that register widget area in footer.
 */
function digger_register_custom_widget_area() {
	register_sidebar(
		array(
			'id'            => 'footer-widget-area',
			'name'          => esc_html__( 'Footer widget area', 'digger' ),
			'description'   => esc_html__( 'Widget Area in Footer of the site', 'digger' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="widget-title-holder"><h3 class="widget-title">',
			'after_title'   => '</h3></div>',
		)
	);
}
/**
 * ENQUEUE EDITOR STYLES
 */
if ( ! function_exists( 'digger_editor_styles' ) ) :
	/**
	 * Ads CSS Style file for the editor in Admin.
	 */
	function digger_editor_styles() {
		add_editor_style(
			array(
				'./editor-style.css',
			)
		);
	}
	add_action( 'admin_init', 'digger_editor_styles' );
endif;
