<?php
/**
 * Custom comments template
 *
 * @package WordPress
 * @subpackage Digger
 * @since Digger 1.0.1
 */

if ( ! function_exists( 'diggerComment' ) ) {

	/**
	 * Displaying a comment
	 *
	 * @param object  $comment comment.
	 * @param array   $args comment.
	 * @param integer $depth comment.
	 * @return void the content already echo.
	 */
	function digger_comment( $comment, $args, $depth ) {

		if ( 'pingback' === $comment->comment_type || 'trackback' === $comment->comment_type ) {
			echo '<li id="comment-';
				comment_ID();
				echo '" ';
				comment_class( 'comment-type-pt' );
			echo '>';
			echo '<div class="comment-body media">';
				echo '<div class="media-body">';
					esc_html_e( 'Pingback:', 'digger' );
					comment_author_link();
					edit_comment_link( __( 'Edit', 'digger' ), '<span class="edit-link">', '</span>' );
				echo '</div>';
			echo '</div>';
		} else {
			echo '<li id="comment-';
				comment_ID();
				echo '" ';
				comment_class( empty( $args['has_children'] ) ? '' : 'parent media' );
			echo '>';

			echo '<article id="div-comment-';
				comment_ID();
			echo '" class="comment-body media">';

				// Comment content.
				echo '<div class="comment-content media-body">';
					echo '<div class="comment-author vcard">';
						echo '<div class="comment-metadata">';
						echo '<div class="comment-avatar me-2">' . get_avatar( $comment, $args['avatar_size'] ) . '</div>';
						// Author.
						echo '<span class="fw-bold">' . esc_html( get_comment_author() ) . '</span><br>';
						// Date-time.
						echo '<time datetime="';
							comment_time( 'c' );
						echo '">';
						/* translators: %1$s: Comment date, %2$s: Comment time. */
						printf( esc_attr( '%1$s at %2$s', 'digger' ), esc_html( get_comment_date() ), esc_html( get_comment_time() ) );
						echo '</time>';
						// End date-time.
						echo '</div><!-- .comment-metadata -->';
						// If comment was not approved.
			if ( '0' === $comment->comment_approved ) {
				echo '<div class="comment-awaiting-moderation text-warning"> <span class="glyphicon glyphicon-info-sign"></span> ';
					esc_html_e( 'The comment is in moderation.', 'digger' );
				echo '</div>';
			}

					echo '</div><!-- .comment-author -->';

					// Comment content body.
					comment_text();
					// End comment content body.

					// Reply link.
					comment_reply_link(
						array_merge(
							$args,
							array(
								'add_below'  => 'div-comment',
								'depth'      => $depth,
								'max_depth'  => $args['max_depth'],
								'reply_text' => esc_html__( 'Reply', 'digger' ),
								'login_text' => esc_html__( 'Sign in to reply', 'digger' ),
							)
						)
					);
				// End reply link.
				echo '</div><!-- .comment-content -->';
				// End comment content.
			echo '</article><!-- .comment-body -->';
		}
	}
}

add_action( 'wp_enqueue_scripts', 'digger_enqueue_comment_reply' );
/**
 * Comments reply and forms
 */
function digger_enqueue_comment_reply() {
	if ( is_singular() ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_filter( 'comment_form_fields', 'digger_move_comment_field_to_bottom' );
/**
 * Moving Comment field to the bottom
 *
 * @param array $fields comment.
 */
function digger_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
