<?php
/**
 * Bootstrap 5 Pagination Functionality
 *
 * @package WordPress
 * @subpackage Digger
 * @since Digger 1.0.1
 */

/**
 * Bootstrap 5 Pagination Function
 */
function digger_boostrap_5_pagination() {
	if ( is_singular() ) {
		return;
	}
	global $wp_query;

	/**
	 * Check number of pages
	 */
	if ( $wp_query->max_num_pages <= 1 ) {
		return;
	}
	$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
	$max   = intval( $wp_query->max_num_pages );

	/** Add current page to the array */
	if ( $paged >= 1 ) {
		$links[] = $paged;
	}
	/** Add the pages around the current page to the array */
	if ( $paged >= 3 ) {
		$links[] = $paged - 1;
		$links[] = $paged - 2;
	}

	if ( ( $paged + 2 ) <= $max ) {
		$links[] = $paged + 2;
		$links[] = $paged + 1;
	}

	echo '<div class="pagination-container"><ul class="pagination">' . "\n";

	/** Link to first page, plus ellipses if necessary */
	if ( ! in_array( 1, $links, true ) ) {
		if ( 1 === $paged ) {
			echo '<li class="page-item active"><a class="page-link" href="' . esc_url( get_pagenum_link( 1 ) ) . '">1</a></li>';
		} else {
			echo '<li class="page-item"><a class="page-link" href="' . esc_url( get_pagenum_link( 1 ) ) . '">1</a></li>';
		}

		if ( ! in_array( 2, $links, true ) ) {
			echo '<li class="nopage">…</li>';
		}
	}

	/** Link to current page, plus 2 pages in either direction if necessary */
	sort( $links );
	foreach ( (array) $links as $link ) {
		if ( $link === $paged ) {
			echo '<li class="page-item active"><a class="page-link" href="' . esc_url( get_pagenum_link( $link ) ) . '">' . esc_attr( $link ) . '</a></li>';
		} else {
			echo '<li class="page-item"><a class="page-link" href="' . esc_url( get_pagenum_link( $link ) ) . '">' . esc_attr( $link ) . '</a></li>';
		}
	}

	/** Link to last page, plus ellipses if necessary */
	if ( ! in_array( $max, $links, true ) ) {
		if ( ! in_array( $max - 1, $links, true ) ) {
			echo '<li class="nopage">…</li>' . "\n";
		}
		if ( $max === $paged ) {
			echo '<li class="page-item active"><a class="page-link" href="' . esc_url( get_pagenum_link( $max ) ) . '">' . esc_attr( $max ) . '</a></li>';
		} else {
			echo '<li class="page-item"><a class="page-link" href="' . esc_url( get_pagenum_link( $max ) ) . '">' . esc_attr( $max ) . '</a></li>';
		}
	}

	echo '</ul></div>' . "\n";

}
add_filter( 'next_posts_link_attributes', 'digger_boostrap_5_pagination_posts_link_attributes' );
add_filter( 'previous_posts_link_attributes', 'digger_boostrap_5_pagination_posts_link_attributes' );
/**
 * Bootstrap 5 Post Link Class
 */
function digger_boostrap_5_pagination_posts_link_attributes() {
	return 'class="page-link"';
}
