<?php
/**
 * The template for displaying all single posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package WordPress
 * @subpackage Digger
 * @since Digger 1.0.3
 */

get_header();
while ( have_posts() ) :
	the_post();
	?>
<section id="single-title">
	<div class="container">
		<div class="row border-bottom py-3 py-md-5 mb-3 mb-md-5">
			<div class="col-12 col-md-10 offset-md-1">
				<header class="entry-header">
					<?php
					the_title( '<h1 class="entry-title">', '</h1>' );
					?>
					<?php
					if ( get_the_modified_time( 'U' ) > get_the_time( 'U' ) ) {
						echo '<span class="text-muted"><small>' . esc_html__( 'Updated', 'digger' ) . ' ' . esc_html( get_the_modified_time( get_option( 'date_format' ) ) ) . '</small></span>';
					} else {
						echo '<span class="text-muted"><small>' . esc_html__( 'Published', 'digger' ) . ' ' . get_the_date() . '</small></span>';
					}
					?>
				</header>
			</div>
		</div>
	</div>
</section>
<section id="single-content" class="content-area">
<div class="container">
	<div class="row mb-3">
		<div class="col-12 col-md-8 offset-md-2">
				<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
					<div class="entry-content">
						<?php
						the_content();
							wp_link_pages(
								array(
									'before'   => '<nav class="page-links clearfix" aria-label="' . esc_attr__( 'Page', 'digger' ) . '">',
									'after'    => '</nav>',
									/* translators: %: Page number. */
									'pagelink' => esc_html__( 'Page %', 'digger' ),
								)
							);
						?>
					</div>
					<?php
					if ( get_edit_post_link() ) :
						?>
						<div class="edit-block my-2 clearfix">
							<?php
							edit_post_link(
								sprintf(
									/* translators: %s: Post title. Only visible to screen readers. */
									esc_html__( 'Edit %s', 'digger' ),
									'<span class="screen-reader-text">' . get_the_title() . '</span>'
								),
								'<span class="edit-link">',
								'</span>'
							);
							?>
						</div>
					<?php endif; ?>
				</article>
		</div>        
	</div>
</div>
</section>
<section id="single-meta">
<div class="container">
	<div class="row mb-3 mb-md-5">
		<div class="col-12 col-md-8 offset-md-2">
			<small>
				<?php
					echo esc_html__( 'Published', 'digger' ) . ' ' . get_the_date() . '<br>';
					echo esc_html__( 'Category', 'digger' ) . ': ';
					the_category( ', ' );
				if ( has_tag() ) {
					echo '<br>' . esc_html__( 'Tags', 'digger' ) . ': ';
					the_tags( '', ', ', '' );
				}
				if ( get_post_meta( $post->ID, 'source', true ) ) {
					$digger_original_link = get_post_meta( $post->ID, 'source', true );
					echo '<br><a href="' . esc_attr( $digger_original_link ) . '" rel="noopener nofollow" target="_blank">' . esc_html__( 'Source', 'digger' ) . '</a>';
				}
				?>
			</small>
		</div>
	</div>
</div>
</section>
<section id="single-author">
<div class="container">
	<div class="row mb-3 mb-md-5">
		<div class="col-12 col-md-8 offset-md-2">
			<div class="postauthor-wrap">
				<span itemscope itemprop="image" alt="<?php the_author_meta( 'display_name' ); ?>">
					<?php
					if ( function_exists( 'get_avatar' ) ) {
						echo get_avatar( get_the_author_meta( 'email' ), '100' );
					}
					?>
				</span>				 
				<h5 class="vcard author" itemprop="url" rel="author">
					<a href="<?php the_author_meta( 'user_url' ); ?>" class="fn" itemprop="name"><span itemprop="author" itemscope itemtype="https://schema.org/Person"><?php the_author_meta( 'display_name', $post->post_author ); ?></span></a>
				</h5>
				<p class="text-muted mb-1"><?php the_author_meta( 'description' ); ?></p>
			</div>
		</div>
	</div>
</div>
</section>
	<?php
	if ( comments_open() || get_comments_number() ) :
		?>
	<section id="single-comments">
		<div class="container">
			<div class="row mb-3 mb-md-5">
				<div class="col-12 col-md-8 offset-md-2">
					<?php comments_template(); ?>
				</div>
			</div>
		</div>
	</section>
		<?php
	endif;
	?>
	<?php
endwhile;
get_footer();
